@@ -258,21 +258,21 @@ class DesktopNotifier:
         :param urgency: Notification level: low, normal or critical. This may be
             interpreted differently by some implementations, for instance causing the
             notification to remain visible for longer, or may be ignored.
-        :param icon: URI string, :class:`pathlib.Path` or icon name to use for the
-            notification, typically the app icon. This will replace the icon specified
-            by :attr:`app_icon`. Will be ignored on macOS.
+        :param icon: Optional URI string, :class:`pathlib.Path` or icon name to use. If
+            given, this will replace the icon specified by :attr:`app_icon`. Will be
+            ignored on macOS.
         :param buttons: A list of buttons with callbacks for the notification.
-        :param reply_field: An optional reply field to show with the notification. Can
-            be used for instance in chat apps.
-        :param on_clicked: Callback to call when the notification is clicked. The
-            callback will be called without any arguments. This is ignored by some
+        :param reply_field: Optional reply field to show with the notification. Can be
+            used for instance in chat apps.
+        :param on_clicked: Optional callback to call when the notification is clicked.
+            The callback will be called without any arguments. This is ignored by some
             implementations.
-        :param on_dismissed: Callback to call when the notification is dismissed. The
-            callback will be called without any arguments. This is ignored by some
-            implementations.
-        :param attachment: URI string or :class:`pathlib.Path` for an attachment to the
-            notification such as an image, movie, or audio file. A preview of this
-            attachment may be displayed together with the notification. Different
+        :param on_dismissed: Optional callback to call when the notification is
+            dismissed. The callback will be called without any arguments. This is
+            ignored by some implementations.
+        :param attachment: Optional URI string or :class:`pathlib.Path` for an
+            attachment to the notification such as an image, movie, or audio file. A
+            preview of this may be displayed together with the notification. Different
             platforms and Linux notification servers support different types of
             attachments. Please consult the platform support section of the
             documentation.
@@ -283,8 +283,7 @@ class DesktopNotifier:
 
         :returns: The scheduled notification instance.
         """
-
-        if not icon:
+        if icon is None:
             icon = self.app_icon
         elif isinstance(icon, Path):
             icon = icon.as_uri()
